import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
* This class creates an extension of JPanel that allows
* the user to play rock paper scissors against the computer by
* choosing their move with a button, and seeing the result of
* their move.
* @author Kenneth Marino
* @version 1.0 2/24/12
*/
public class RPSPanel extends JPanel
{
	// Instance variables
	// JButtons
	private JButton rockButton;
	private JButton paperButton;
	private JButton scissorsButton;
	// JLabels
	private JLabel opponentLabel;
	private JLabel resultLabel;
	private JLabel scoreLabel;
	// Other
	private RPSScoreKeeper score;
	
	/**
	* The constructor initializes all of the GUI components including three 
	* buttons with rock paper and scissors icons, complete with actionListeners
	* and three labels for seeing output.
	*/
	public RPSPanel()
	{
		// Load all of the images into icons
		ImageIcon rockImg = new ImageIcon("rock.png");
		ImageIcon paperImg = new ImageIcon("paper.png");
		ImageIcon scissorsImg = new ImageIcon("scissors.png");
		
		// Create buttons and add action listeners
		rockButton = new JButton(rockImg);
		rockButton.addActionListener(new RPSListener(RPSThrow.ROCK));
		paperButton = new JButton(paperImg);
		paperButton.addActionListener(new RPSListener(RPSThrow.PAPER));
		scissorsButton = new JButton(scissorsImg);
		scissorsButton.addActionListener(new RPSListener(RPSThrow.SCISSORS));
		
		// Create labels and RPSScoreKeeper
		score = new RPSScoreKeeper();
		opponentLabel = new JLabel("Choose a throw to run a game.");
		resultLabel = new JLabel();
		scoreLabel = new JLabel(score.toString());
		
		// Adds everything to the panel
		add(rockButton);
		add(paperButton);
		add(scissorsButton);
		add(opponentLabel);
		add(resultLabel);
		add(scoreLabel);
		
		// Set preferred size
		setPreferredSize(new Dimension(275, 150));
	}
	
	/**
	* Action listener for rock paper scissors buttons. Input parameter to constructor
	* determines it's specific behavoir.
	* @author Kenneth Marino
	* @version 1.0 2/24/12	
	*/
	private class RPSListener implements ActionListener
	{
		private int choice;
		
		/**
		* Constructor. Takes in parameter representing rock, paper or
		* scissors. Will use this in actionPerformed.
		* @param choice The user's choice of "attack"
		*/
		public RPSListener(int choice)
		{
			this.choice = choice;
		}
		
		/**
		* When this method is invoked, creates two throws, and determines
		* who the winner is. Then makes necessary updates to resultLabel, 
		* opponentLabel, scoreLabel and score.
		* @param event ActionEvent (not used)
		*/
		public void actionPerformed(ActionEvent event)
		{
			// Create two throw objects
			RPSThrow userThrow = new RPSThrow(choice);
			RPSThrow computerThrow = new RPSThrow();
			
			// Determine the winner and update result label and score
			if (userThrow.beats(computerThrow))
			{
				resultLabel.setText("You win!");
				score.addWin();
			}
			else if (computerThrow.beats(userThrow))
			{
				resultLabel.setText("You lose!");
				score.addLoss();
			}
			else
			{
				resultLabel.setText("You tie!");
				score.addTie();
			}
			
			// Update opponentLabel
			opponentLabel.setText("The computer chose " + computerThrow + ".");
			
			// Update scoreLabel
			scoreLabel.setText(score.toString());
		}
	}
	
	/**
	* This  main method simply creates a new JFrame, does the proper initialization,
	* creates a new RPSPanel, packs, and displays it.
	* @param args Command line arguments (unused)
	*/
	public static void main(String[] args)
	{
		// Create frame and do initialization
		JFrame frame = new JFrame("Rock Paper Scissors");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		// Create new RPSPanel
		RPSPanel panel = new RPSPanel();
		
		
		// Add panel, pack and display
		frame.add(panel);
		frame.pack();
		frame.setVisible(true);		
	}
}