import java.util.Random;

/**
* This class represents one throw of rock-paper-scissors. Stores
* constants related to different throws. Value determined wither by
* parameter in constructor, or choosen randomly for parameterless
* constructor.
* @author Kenneth Marino
* @version 1.0 2/24/12
*/
public class RPSThrow
{
	// Constants
	public final static int ROCK = 0;
	public final static int PAPER = 1;
	public final static int SCISSORS = 2;
	
	// Instance variables
	private int choice;
	
	// Class variables
	private static Random rand = new Random();
	
	/**
	* One parameter constructor, sets the choice by the input.
	* @param choice The user's choice of rock, paper or scissors
	*/
	public RPSThrow(int choice)
	{
		this.choice = choice;
	}
	
	/**
	* Parameterless constructor. Randomly chooses rock, paper or
	* scissors.
	*/
	public RPSThrow()
	{
		// Chooses value between 0 and 2 representing ROCK, PAPER, and SCISSORS
		choice = rand.nextInt(3);
	}
	
	/**
	* Returns the choice 
	* @return User's choice (rock, paper or scissors)
	*/
	public int getChoice()
	{
		return choice;
	}
	
	/**
	* Compares the choice in the calling object to the one 
	* given as input. Returns true if the calling object's choice
	* beats the parameter's choice.
	* @param other A RPSThrow to compare to the calling object
	* @return True if the calling object beats the parameter, false otherwise
	*/
	public boolean beats(RPSThrow other)
	{
		// For each player choice
		int opponentChoice = other.getChoice();
		if (choice == ROCK)
		{
			// Rock beats scissors
			if (opponentChoice == SCISSORS)
				return true;
			else
				return false;
		}
		else if (choice == PAPER)
		{
			// Paper beats rock
			if (opponentChoice == ROCK)
				return true;
			else
				return false;
		}
		else
		{
			if (opponentChoice == PAPER)
				return true;
			else
				return false;
		}
	}
	
	/**
	* Returns a string representation of the object based on 
	* choice.
	* @return String representation of object
	*/
	public String toString()
	{
		String out;
		if (choice == ROCK)
			out = "rock";
		else if (choice == PAPER)
			out = "paper";
		else
			out = "scissors";
		return out;
	}
}